% Stock Data Analysis Script
% 
% This script performs data analysis on historical stock price data retrieved
% from Alpha Vantage API. It calculates the mean and standard deviation of
% daily returns for a set of stocks and displays the results.
%
% Author: Abraham Reines
% Date: May 23, 2023
%
% Instructions:
% 1. Make sure you have MATLAB installed.
% 2. Run the script after providing the necessary inputs.
% 3. The script imports processed data from CSV files generated by the Python script.
% 4. The processed data includes columns for daily returns and cumulative returns.
% 5. The script calculates the mean and standard deviation of daily returns for each stock.
% 6. The results are displayed in the MATLAB Command Window.
%
% Note: Ensure that the Python script has been executed to generate the required data files.
%

% Clear the workspace
clear;
clc;

% Import the processed data from CSV files
AAPL_data = readtable('AAPL_processed_data.csv');
GOOGL_data = readtable('GOOGL_processed_data.csv');
MSFT_data = readtable('MSFT_processed_data.csv');

% Extract the 'Daily Return' column from each dataset
AAPL_daily_return = AAPL_data{:, 'DailyReturn'};
GOOGL_daily_return = GOOGL_data{:, 'DailyReturn'};
MSFT_daily_return = MSFT_data{:, 'DailyReturn'};

% Calculate mean and standard deviation of daily returns
AAPL_mean = mean(AAPL_daily_return, 'omitnan');
AAPL_std = std(AAPL_daily_return, 'omitnan');

GOOGL_mean = mean(GOOGL_daily_return, 'omitnan');
GOOGL_std = std(GOOGL_daily_return, 'omitnan');

MSFT_mean = mean(MSFT_daily_return, 'omitnan');
MSFT_std = std(MSFT_daily_return, 'omitnan');

% Display the results
disp('Mean and Standard Deviation of Daily Returns:');
disp(['AAPL: Mean = ', num2str(AAPL_mean), ', Std = ', num2str(AAPL_std)]);
disp(['GOOGL: Mean = ', num2str(GOOGL_mean), ', Std = ', num2str(GOOGL_std)]);
disp(['MSFT: Mean = ', num2str(MSFT_mean), ', Std = ', num2str(MSFT_std)]);
